==> dasu_3.02.jar: edu/northwestern/dasu/drools/FactMeasurement.java <==

/**
 * Dasu Project
 *
 * File:         FactMeasurement.java
 * RCS:          $Id$
 * Description:  FactMeasurement class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:19:13 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import java.util.LinkedList;
import edu.northwestern.dasu.DasuConfiguration;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurement class ...
 */
public abstract class FactMeasurement<T>  extends FactTemplate {

	protected int interval = DasuConfiguration.getInstance().getPeerUpdateIntervalSec();
	protected int timeSpan = DasuConfiguration.getInstance().getTimeSpan();
	protected int maxNumEntries = timeSpan * 60 / interval; // => window size
	protected boolean windowFull = false;
	protected Float stdevFactor = 2.3F;

	/* list of past measurements */
	protected LinkedList<T> entryList = new LinkedList<T>();
	
	/*
	 *  Used to calculate average rates before download completed
	 *  Holds 3 times the number of entries in a movingWindow 
	 */
	public LinkedList<T> entryLog = new LinkedList<T>();
	protected long lastModified = -1L;
	protected boolean DEBUG = false;

	public FactMeasurement() {
		
	}
	
	public FactMeasurement(int timeSpan) {
		this.timeSpan = timeSpan;
		maxNumEntries = timeSpan * 60 / interval;
	}
	
	public boolean isWindowFull() {
		return windowFull;
	}
	
	public void setWindowFull(boolean windowFull) {
		boolean temp = this.windowFull;
		this.windowFull = windowFull;
        pcs.firePropertyChange("windowFull", new Boolean(temp), new Boolean(windowFull));
	}

	
	public void setstdevFactor(float stdevFactor) {
		this.stdevFactor = stdevFactor;
	}
		
	public void setTimeSpan(int tmsp) {
		timeSpan = tmsp;
	}
		
	public Float getStdevFactor() {
		return stdevFactor;
	}
	
//	public LinkedList<T> getEntryList() {
//		return entryList;
//	}


	public void addEntry(T ent) {

		if (entryList.size() == maxNumEntries) {
			entryList.removeFirst();
			windowFull = true;
		}
		
		if (entryLog.size() == 3 * maxNumEntries)
			entryLog.removeFirst();

		entryLog.add(ent);
		entryList.add(ent);
		updateAll(ent);
		updateTimeStamp();
		
	}
		
	public void updateAll(T ent){

	}
		
	public int getInterval() {
		return interval;
	}
	public int getTimeSpan() {
		return timeSpan;
	}
	public int getMaxNumEntries() {
		return maxNumEntries;
	}
	
	public long getLastModified() {
		return lastModified;
	}
	
	public void setInterval(int interval) {
		this.interval = interval;
	}
	public void setMaxNumEntries(int maxNumEntries) {
		this.maxNumEntries = maxNumEntries;
	}
	
	public void setStdevFactor(float stdevFactor) {
		this.stdevFactor = stdevFactor;
	}

	public void setLastModified(Long lastModified) {
		Long temp = this.lastModified;
		this.lastModified = lastModified;
        pcs.firePropertyChange("lastModified", new Long(temp), new Long(lastModified));			
	}
	
	protected void updateTimeStamp() {
		setLastModified(System.nanoTime());
	}

		
}

==> dasu_4.11.jar: edu/northwestern/dasu/drools/FactMeasurement.java <==

/**
 * Dasu Project
 *
 * File:         FactMeasurement.java
 * RCS:          $Id$
 * Description:  FactMeasurement class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:19:13 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import java.util.LinkedList;
import java.util.logging.Logger;

import edu.northwestern.dasu.DasuConfiguration;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurement class ...
 */
public abstract class FactMeasurement<T>  extends FactTemplate {

	protected int interval = DasuConfiguration.getInstance().getPeerUpdateIntervalSec();
	protected int timeSpan = DasuConfiguration.getInstance().getTimeSpan();
	protected int maxNumEntries = timeSpan * 60 / interval; // => window size
	protected boolean windowFull = false;
	protected Float stdevFactor = 2.3F;

	/* list of past measurements */
	public LinkedList<T> entryList = new LinkedList<T>();
	
	/*
	 *  Used to calculate average rates before download completed
	 *  Holds 3 times the number of entries in a movingWindow 
	 */
	public LinkedList<T> entryLog = new LinkedList<T>();
	protected long lastModified = -1L;
	protected boolean DEBUG = false;
	protected final static Logger LOGGER = Logger.getLogger("edu.northwestern.dasu");

	public FactMeasurement() {
		
	}
	
	public FactMeasurement(int timeSpan) {
		this.timeSpan = timeSpan;
		maxNumEntries = timeSpan * 60 / interval;
	}
	
	public boolean isWindowFull() {
		return windowFull;
	}
	
	public void setWindowFull(boolean windowFull) {
		boolean temp = this.windowFull;
		this.windowFull = windowFull;
        pcs.firePropertyChange("windowFull", new Boolean(temp), new Boolean(windowFull));
	}

	
	public void setstdevFactor(float stdevFactor) {
		this.stdevFactor = stdevFactor;
	}
		
	public void setTimeSpan(int tmsp) {
		timeSpan = tmsp;
	}
		
	public Float getStdevFactor() {
		return stdevFactor;
	}
	
//	public LinkedList<T> getEntryList() {
//		return entryList;
//	}


	public void addEntry(T ent) {

		if (entryList.size() == maxNumEntries) {
			entryList.removeFirst();
			windowFull = true;
		}
		
		if (entryLog.size() == 3 * maxNumEntries)
			entryLog.removeFirst();

		entryLog.add(ent);
		entryList.add(ent);
		updateAll(ent);
		updateTimeStamp();
		
	}
		
	public void updateAll(T ent){

	}
		
	public int getInterval() {
		return interval;
	}
	public int getTimeSpan() {
		return timeSpan;
	}
	public int getMaxNumEntries() {
		return maxNumEntries;
	}
	
	public long getLastModified() {
		return lastModified;
	}
	
	public void setInterval(int interval) {
		this.interval = interval;
	}
	public void setMaxNumEntries(int maxNumEntries) {
		this.maxNumEntries = maxNumEntries;
	}
	
	public void setStdevFactor(float stdevFactor) {
		this.stdevFactor = stdevFactor;
	}

	public void setLastModified(Long lastModified) {
		Long temp = this.lastModified;
		this.lastModified = lastModified;
        pcs.firePropertyChange("lastModified", new Long(temp), new Long(lastModified));			
	}
	
	protected void updateTimeStamp() {
		setLastModified(System.nanoTime());
	}

		
}
